fn write_to_test_logs<S>(line: S, bypass_test_capture: bool)Expand description
Write line to stdout, so it can be seen in the test logs.
Set bypass_test_capture to true or
use cargo test -- --nocapture to see this output.
May cause weird reordering for stdout / stderr. Uses stdout even if the original lines were from stderr.